==> HostCMS.Free_6.7.tar.gz: modules/company/department/i18n/en.php <==
<?php
/**
 * Company Department
 *
 * @package HostCMS
 * @subpackage Company
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Departments',
	'title' => 'The structure of the company',
	'company' => '<acronym title="Company">Company</acronym>',
	'warning' => 'There are no companies associated with site',
	'add_form_title' => 'Add department',
	'edit_form_title' => 'Edit department',
	'delete_form_title' => 'Delete department',
	'add_user_title' => 'Add user into department',
	'edit_user_title' => 'Edit user',
	'delete_user_title' => 'Delete user from department',
	'name' => '<acronym title="Name of department">Name</acronym>',
	'parent_id' => '<acronym title="Parent Department">Parent Department</acronym>',
	'address' => '<acronym title="Address of department">Address</acronym>',
	'description' => '<acronym title="Description of department">Description</acronym>',
	'caption' => '<acronym title="Name of department">Department</acronym>',
	'addUserTitleAction' => 'Add user',
	'editTitleAction' => 'Edit department',
	'deleteTitleAction' => 'Delete department',
	'caption_block_users' => 'Employees',
	'editUserDepartmentPostTitleAction' => 'Edit',
	'deleteUserDepartmentPostTitleAction' => 'Delete from department',
	'add' => 'Add',
	'edit' => 'Edit',
	'cancel' => 'Cancel',

	'add_success' => 'Department added successfully!',
	'apply_success' => 'Information modified successfully.',

	'markDeleted_success' => 'Department deleted successfully.',
	'markDeleted_error' => 'Department has not been deleted!',
	'delete_success' => 'Department deleted successfully.',

	'moduleTitleAction' => 'Module access',
	'actionTitleAction' => 'Action access',


	'moveMessage' => 'Do you really want to move the department?',
	'deleteMessage' => 'Do you really want to delete the department and its sub-departments?',
	'deleteUserMessage' => 'Do you really want to remove an employee from the department?',

	'addUserToHeads_success' => '%s is appointed the head of the department %s',
	'addUserToHeads_error' => '%s is already %s in %s',
	'deleteUserFromHeads_success' => '%s is dismissed from the department head %s',

	'changeUserDepartmentPost_success' => '%s is transferred to the post %s in %s',
	'addUserToDepartmentPost_success' => '%s is appointed to the post %s in %s',

	'addUser_success' => 'The employee was added to the department.',
	'applyUser_success' => 'Information about the position of the employee in the department is changed.',
	'addUser_error' => 'The employee already works in this position in this department.',

	'deleteUserFromDepartment_success' => "The employee %s remove from this position %s in %s",

	'departmentExistence_error' => 'Error! There is no such department.',
);

==> HostCMS.Free_7.0.tar.gz: modules/company/department/i18n/en.php <==
<?php
/**
 * Company Department
 *
 * @package HostCMS
 * @subpackage Company
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2023 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Departments',
	'title' => 'The structure of the company',
	'company' => 'Company',
	'warning' => 'There are no companies associated with site',
	'add_form_title' => 'Add department',
	'edit_form_title' => 'Edit department',
	'delete_form_title' => 'Delete department',
	'add_user_title' => 'Add user into department',
	'edit_user_title' => 'Edit user',
	'delete_user_title' => 'Delete user from department',
	'name' => 'Name',
	'parent_id' => 'Parent Department',
	'address' => 'Address',
	'description' => 'Description',
	'caption' => 'Department',
	'addUserTitleAction' => 'Add user',
	'editTitleAction' => 'Edit department',
	'deleteTitleAction' => 'Delete department',
	'caption_block_users' => 'Employees',
	'editUserDepartmentPostTitleAction' => 'Edit',
	'deleteUserDepartmentPostTitleAction' => 'Delete from department',
	'add' => 'Add',
	'edit' => 'Edit',
	'cancel' => 'Cancel',
	'add_success' => 'Department added successfully!',
	'delete_success' => 'Department deleted successfully.',
	'moduleTitleAction' => 'Module access',
	'actionTitleAction' => 'Action access',
	'moveMessage' => 'Do you really want to move the department?',
	'deleteMessage' => 'Do you really want to delete the department and its sub-departments?',
	'deleteUserMessage' => 'Do you really want to remove an employee from the department?',
	'addUserToHeads_success' => '%s is appointed the head of the department %s',
	'addUserToHeads_error' => '%s is already %s in %s',
	'deleteUserFromHeads_success' => '%s was dismissed from the department head %s',
	'changeUserDepartmentPost_success' => '%s is transferred to the post %s in %s',
	'addUserToDepartmentPost_success' => '%s is appointed to the post %s in %s',
	'addUser_success' => 'The employee was added to the department.',
	'applyUser_success' => 'Information about the position of the employee in the department is changed.',
	'addUser_error' => 'The employee already works in this position in this department.',
	'deleteUserFromDepartment_success' => "The employee %s remove from this position %s in %s",
	'departmentExistence_error' => 'Error! There is no such department.',
	'addDepartmentButtonTitle' => 'Add department',
	'editDepartment_success' => 'Department changed successfully.',
	'editDepartment_errorDependetDepartment' => 'Error! Cannot move a department to its child department.',
	'changeParentDepartment_success' => 'Parent department for "%s" changed.',
	'deleteDepartment_success' => 'Department deleted successfully.',
	'deleteDepartment_error' => 'Department not deleted',
	'undelete_success' => 'Department restored successfully.',
	'close_modal_confirm' => 'Are you sure you want to cancel?',
);
